const MINUTE = 1000 * 60;
const HEALTH_CHECK_TIMEOUT = 10 * MINUTE;

setTimeout(() => {
  if (window.FUGO_HEALTH_CHECK) {
    console.log("Fugo health check passed, no need to reload.");
    return;
  }
  console.log("Fugo health check didn't pass in time");
  fetch("/functions/notify-slack", {
    method: "POST",
    headers: {
      "Content-type": "application/json",
    },
    body: JSON.stringify({ message: "Fugo health check didn't pass in time" }),
  });
}, HEALTH_CHECK_TIMEOUT);

function clearCache() {
  caches
    .keys()
    .then((keyList) => {
      return Promise.all(
        keyList.map((key) => {
          return caches.delete(key);
        })
      );
    })
    .catch((error) => {
      console.log("Failed to clear web cache", error);
    });
}

function clearIDB() {
  new Promise((resolve, reject) => {
    const openreq = indexedDB.open("keyval-store", 1);
    openreq.onerror = () => {
      reject(openreq.error);
    };
    openreq.onsuccess = () => {
      resolve(openreq.result);
    };
  })
    .then((db) => {
      return new Promise((resolve, reject) => {
        const transaction = db.transaction("keyval", "readwrite");
        transaction.oncomplete = () => {
          resolve();
        };
        transaction.onabort = transaction.onerror = () => {
          reject(transaction.error);
        };
        const store = transaction.objectStore("keyval");
        store.clear();
      });
    })
    .catch((error) => {
      console.log("Failed to clear indexedDB", error);
    });
}

function clearLocalStorage() {
  localStorage.clear();
}
